@@ -19,9 +19,9 @@
 #ifndef TEXT_SCROLLER_H
 #define TEXT_SCROLLER_H
 
+#include <memory>
 #include <string>
 #include <vector>
-
 class Font;
 class Game_window;
 class Shape;
@@ -30,15 +30,18 @@ class Palette;
 
 class TextScroller {
 private:
-	Font *font;
-	Shape *shapes;
-	std::vector<std::string> *text;
+	std::shared_ptr<Font>     font;
+	Shape*                    shapes;
+	std::vector<std::string>* text;
+
 public:
-	TextScroller(const char *archive, int index, Font *fnt, Shape *shp);
+	TextScroller(
+			const char* archive, int index, std::shared_ptr<Font> fnt,
+			Shape* shp);
 	~TextScroller();
-	bool run(Game_window *gwin);
-	int show_line(Game_window *gwin, int left, int right, int y, int index);
-	int get_count();
+	bool run(Game_window* gwin);
+	int  show_line(Game_window* gwin, int left, int right, int y, int index);
+	int  get_count();
 };
 
 #endif
